# RamPy
=======

[![Build Status](https://travis-ci.org/charlesll/rampy.svg?branch=master)](https://travis-ci.org/charlesll/rampy)
[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.1168729.svg)](https://doi.org/10.5281/zenodo.1168729) [![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/charlesll/rampy.git/master)
![GitHub](https://img.shields.io/github/license/charlesll/rampy)

Rampy is a Python library that aims at helping processing spectroscopic data, such as Raman, Infrared or XAS spectra. It offers various functions, for instance to subtract baselines, resample and smooth spectra, perform machine learning classification, etc. It aims at facilitating the use of Python in processing spectroscopic data. It integrates within a workflow that uses Numpy/Scipy/Matplotlib as well as optimisation libraries such as lmfit, emcee or PyMC, for instance.

Check the documentation for more information!

- **Documentation:** https://rampy.readthedocs.io
- **Examples** see docs and https://github.com/charlesll/rampy/tree/master/examples
- **Source code:** https://github.com/charlesll/rampy/tree/master/rampy
- **Contributing:** https://github.com/charlesll/rampy/blob/master/CONTRIBUTING.md
- **Bug reports:** https://github.com/charlesll/rampy/issues
- **Contact** lelosq@ipgp.fr
